@@ -2,7 +2,7 @@ use criterion::{black_box, criterion_group, criterion_main, Criterion};
 
 use rucash;
 
-const URI: &str = "sqlite://tests/sqlite/sample/complex_sample.gnucash";
+const URI: &str = "sqlite://tests/db/sqlite/complex_sample.gnucash";
 
 fn benchmark_sql_query(c: &mut Criterion) {
     let book = rucash::Book::<sqlx::Sqlite>::new(URI).unwrap();
@@ -16,7 +16,7 @@ fn benchmark_vec_filter(c: &mut Criterion) {
     c.bench_function("vec filter", |b| {
         b.iter(|| {
             let vec = book.accounts().unwrap();
-            let accounts: Vec<rucash::sqlite::Account> = vec
+            let _: Vec<rucash::sqlite::Account> = vec
                 .into_iter()
                 .filter(|x| x.name.to_lowercase().contains(black_box("as")))
                 .collect();
